@@ -68,7 +68,7 @@ class Client(object):
     read_size = 4096
     read_timeout = 5
 
-    def __init__(self, srvaddr, srvport=2000, debug=False):
+    def __init__(self, srvaddr, srvport=4190, debug=False):
         self.srvaddr = srvaddr
         self.srvport = srvport
         self.__debug = debug
@@ -643,3 +643,21 @@ class Client(object):
             return True
         return False
 
+    @authentication_required
+    def checkscript(self, content):
+        """Check whether a script is valid
+
+        See MANAGESIEVE specifications, section 2.12
+
+        :param name: script's content
+        :rtype: boolean
+        """
+        if type(content) is unicode:
+            content = content.encode("utf-8")
+
+        content = "{%d+}%s%s" % (len(content), CRLF, content)
+        code, data = \
+            self.__send_command("CHECKSCRIPT", [content])
+        if code == "OK":
+            return True
+        return False
